@@ -1,5 +1,4 @@
 import os
-from . import Params
 
 class ConfMethods:
 
@@ -9,7 +8,7 @@ class ConfMethods:
 
         return f'{user_path}/teste.conf'
     
-    def write_conf(self, file_path, data: dict):
+    def read_conf(self, file_path, data: dict):
 
         with open(file_path, 'r') as file:
 
@@ -17,9 +16,11 @@ class ConfMethods:
 
         for key, value in data.items():
 
-            if key in Params.params_list:
+            file_dict[f'{key}'] = value
 
-                file_dict[f'{key}'] = value
+        return file_dict
+
+    def write_conf(self, file_path, file_dict):
 
         with open(file_path, 'w') as file:
             
