@@ -32,10 +32,14 @@ class Gateway:
         self._print.print_data(json.loads(self._message))
 
     def emitir_nota_fiscal(self):
+        msg = 'teste'
+
+        with open('C:\\Users\\danilo\\Documents\\NFe.txt', 'w') as ini_file:
+            ini_file.write(msg)
 
         self._message = {'token': self._token}
         self._response.send_message(json.dumps(self._message))
-        self._message = self._response.get_message()
+        self._message = json.loads(self._response.get_message())
     
     def set_erro(self, erro):
 
