@@ -14,9 +14,7 @@ class Response:
     def send_message(self, message):
 
         self._client.sendall(str.encode(message))
-        data = self._client.recv(4096)
-        self._message = data.decode()
-        print(self._message)
+        self._message = self._client.recv(4096).decode('utf-8')
         self._client.close()
 
     def get_message(self):
